from base64 import b64encode
import sys
from StringIO import StringIO

def read_file_to_buffer(filename):
	f = open(filename, "r")
	buf = StringIO(f.read())
	f.close()
	return buf

def print_image(filename):
	data = read_file_to_buffer(filename)
	sys.stdout.write("\033]1337;File=name=%s;size=%d;inline=1:%s\a\n" %
		(b64encode(filename), data.len, b64encode(data.getvalue())))
	data.close()

def push_file(filename):
	data = read_file_to_buffer(filename)
	sys.stdout.write("\033]1337;File=name=%s;size=%d;inline=0:%s\a\n" %
		(b64encode(filename), data.len, b64encode(data.getvalue())))
	data.close()



from distutils.core import setup

setup(name='iterm2_image',
      version='0.1',
      py_modules=['iterm2_image'],
      description='Prints images and sends files using the iTerm2 image extension',
      author='zakx',
      author_email='zakx@koeln.ccc.de',
      url='https://github.com/zakx/iterm2_image',
      classifiers=[
          'Development Status :: 4 - Beta',
          'Environment :: Console',
          'Intended Audience :: Developers',
          'Intended Audience :: System Administrators',
          'Operating System :: MacOS :: MacOS X',
          'Operating System :: POSIX',
          'Programming Language :: Python',
          ],
      )
